#include <owl\dialog.h>
#include <owl\static.h>
#include <owl\gdiobjec.h>
#include "aboutscr.rc"

//////////////////////////////////
// The custom control class.
//////////////////////////////////
class TBitmapCtrl : public TStatic
{
public:
  TBitmapCtrl(TWindow *parent, int resId)
    : TStatic(parent, resId, 0) {};

protected:
  void SetupWindow();
  void CleanupWindow();
  void Paint(TDC &paintDC, bool, TRect&);
  void EvPaint();
  void EvTimer(uint);

private:
  TBitmap *bitmap;
  int upperY;
DECLARE_RESPONSE_TABLE(TBitmapCtrl);
};

DEFINE_RESPONSE_TABLE1(TBitmapCtrl, TStatic)
  EV_WM_PAINT,
  EV_WM_TIMER,
END_RESPONSE_TABLE;

///////////////////////////////////////////////////////////
// TBitmapCtrl::SetupWindow()
///////////////////////////////////////////////////////////
void TBitmapCtrl::SetupWindow()
{
  // Let OWL do the regular setup.
  TStatic::SetupWindow();

  // Load the bitmap.
  TApplication *app = GetApplication();
  HINSTANCE hInstance = app->GetInstance();
  bitmap = new TBitmap(hInstance, BITMAP_1);
  upperY = 0;

  SetTimer(1, 100);
}


void TBitmapCtrl::CleanupWindow()
{
  KillTimer(1);
}

///////////////////////////////////////////////////////////
// TBitmapCtrl::EvPaint()
///////////////////////////////////////////////////////////
void TBitmapCtrl::EvPaint()
{
  // Force a call to the control's Paint() function.
  TWindow::EvPaint();
}

///////////////////////////////////////////////////////////
// TBitmapCtrl::Paint()
///////////////////////////////////////////////////////////
void TBitmapCtrl::Paint(TDC &paintDC, bool, TRect&)
{
  // Display the bitmap.
  TMemoryDC mdc(paintDC);
  mdc.SelectObject(*bitmap);
  paintDC.BitBlt(0, 0, 64, 64 - upperY, mdc, 0, upperY, SRCCOPY);
  paintDC.BitBlt(0, 64 - upperY, 64, upperY, mdc, 0, 0, SRCCOPY);
}


void TBitmapCtrl::EvTimer(uint)
{
  upperY = (++upperY % 64);
  Invalidate(FALSE);
}

//////////////////////////////////
// The dialog box class.
//////////////////////////////////
class TDlgAbout : public TDialog
{
public:
  TDlgAbout::TDlgAbout(TWindow *parent, TResId resId) :
    TDialog(parent, resId) {};

protected:
  void SetupWindow();
};

///////////////////////////////////////////////////////////
// TDlg::SetupWindow()
///////////////////////////////////////////////////////////
void TDlgAbout::SetupWindow()
{
  // Construct the dialog box's custom bitmap control.
  new TBitmapCtrl(this, IDC_BITMAP1);
  // Allow OWL to perform regular setup.
  TDialog::SetupWindow();
}


